@@ -11,7 +11,7 @@ use Moose;
 use MooseX::App::Message::Block;
 
 use overload
-    '""' => "stringify";
+    '""' => "overload";
 
 has 'blocks' => (
     is          => 'ro',
@@ -23,28 +23,64 @@ has 'blocks' => (
     },
 );
 
+has 'exitcode' => (
+    is          => 'ro',
+    isa         => 'Int',
+    predicate   => 'has_exitcode',
+);
+
 around 'BUILDARGS' => sub {
     my $orig = shift;
     my $self = shift;
     my @args = @_;
     
-    my @blocks;
-    foreach my $element (@args) {
-        if (blessed $element
-            && $element->isa('MooseX::App::Message::Block')) {
-            push(@blocks,$element);
-        } else {
-            push(@blocks,MooseX::App::Message::Block->new(
-                header  => $element,
-            ));
+    my $params;
+    if (scalar @args == 1
+        && ref($args[0]) eq 'HASH') {
+        $params = $args[0];
+    } else {
+        $params = {
+            blocks  => [],
+        };
+        my @blocks;
+        foreach my $element (@args) {
+            next
+                unless defined $element;
+            if (blessed $element
+                && $element->isa('MooseX::App::Message::Block')) {
+                push(@{$params->{blocks}},$element);
+            } elsif ($element =~ /^\d+$/ 
+                && $element <= 255
+                && $element >= 0) {
+                $params->{exitcode} = $element;
+            } else {
+                push(@{$params->{blocks}},MooseX::App::Message::Block->new(
+                    header  => $element,
+                ));
+            }
         }
     }
-
-    return $self->$orig({ 
-        blocks  => \@blocks,
-    });
+    
+    return $self->$orig($params);
 };
 
+sub overload {
+    my ($self) = @_;
+    
+    if ($self->has_exitcode) {
+        my $exitcode = $self->exitcode;
+        if ($exitcode == 0) {
+            print $self->stringify;
+        } else {
+            print STDERR $self->stringify;
+        }
+        exit $exitcode;
+    } else {
+        print $self->stringify;
+    }
+    return;
+}
+
 sub stringify {
     my ($self) = @_;
     
@@ -58,7 +94,7 @@ sub stringify {
 
 sub AUTOLOAD { 
     my ($self) = @_;
-    print $self->stringify;
+    $self->overload;
     return $MooseX::App::Null::NULL;
 }
 
@@ -104,12 +140,20 @@ this, no matter if new_with_command fails or not:
 
  MyApp->new_with_command->some_method->only_called_if_successful;
 
+If
+
 =head1 METHODS
 
 =head2 stringify
 
 Stringifies the messages
 
+=head2 overload
+
+This method is called whenever the object is stringified via overload. In this
+case it prints the message on either STDERR or STDOUT, and exits the process
+with the given exitcode (if any).
+
 =head2 add_block
 
 Adds a new message block. Param must be a L<MooseX::App::Message::Block>
@@ -122,6 +166,14 @@ Returns a list on message blocks.
 
 Message block accessor.
 
+=head2 exitcode
+
+Exitcode accessor.
+
+=head2 has_exitcode
+
+Check if exitcode is set.
+
 =head2 OVERLOAD
 
 Stringification of this object is overloaded.
